@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -34,7 +34,7 @@ FilterActionRemoveHeaderTest::~FilterActionRemoveHeaderTest()
 void FilterActionRemoveHeaderTest::shouldHaveDefaultValue()
 {
     MailCommon::FilterActionRemoveHeader filter;
-    QWidget *w = filter.createParamWidget(0);
+    QWidget *w = filter.createParamWidget(nullptr);
     PimCommon::MinimumComboBox *comboBox = dynamic_cast<PimCommon::MinimumComboBox *>(w);
     QVERIFY(comboBox);
     QVERIFY(comboBox->isEditable());
