@@ -56,14 +56,15 @@ static KMime::Content *findMimeNodeForIndex(KMime::Content *node, int &index)
         return node;
     }
 
-    foreach (KMime::Content *child, node->contents()) {
+    const QVector<KMime::Content *> lstContents = node->contents();
+    for (KMime::Content *child : lstContents) {
         KMime::Content *result = findMimeNodeForIndex(child, --index);
         if (result) {
             return result;
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
 QString FilterActionWithCommand::substituteCommandLineArgsFor(const KMime::Message::Ptr &aMsg, QList<QTemporaryFile *> &aTempFileList) const
@@ -114,7 +115,7 @@ QString FilterActionWithCommand::substituteCommandLineArgsFor(const KMime::Messa
 
             if ((*it) == -1) {
                 file.write(aMsg->encodedContent());
-            } else if (aMsg->contents().size() == 0) {
+            } else if (aMsg->contents().isEmpty()) {
                 file.write(aMsg->decodedContent());
             } else {
                 int index = *it; // we pass by reference below, so this is not const
