@@ -40,7 +40,7 @@ class Q_DECL_HIDDEN FilterManager::Private
 {
 public:
     Private(FilterManager *qq)
-        : q(qq), mMailFilterAgentInterface(0), mMonitor(new Akonadi::Monitor), mInitialized(false)
+        : q(qq), mMailFilterAgentInterface(nullptr), mMonitor(new Akonadi::Monitor), mInitialized(false)
     {
         mMailFilterAgentInterface = new org::freedesktop::Akonadi::MailFilterAgent(QStringLiteral("org.freedesktop.Akonadi.MailFilterAgent"),
                 QStringLiteral("/MailFilterAgent"),
@@ -94,8 +94,8 @@ void FilterManager::Private::clear()
 
 using namespace MailCommon;
 
-FilterManager *FilterManager::Private::mInstance = Q_NULLPTR;
-FilterActionDict *FilterManager::Private::mFilterActionDict = Q_NULLPTR;
+FilterManager *FilterManager::Private::mInstance = nullptr;
+FilterActionDict *FilterManager::Private::mFilterActionDict = nullptr;
 
 FilterManager *FilterManager::instance()
 {
@@ -168,7 +168,8 @@ void FilterManager::slotFinishedTagListing(KJob *job)
         qCWarning(MAILCOMMON_LOG) << "failed to retrieve tags " << job->errorString();
     }
     Akonadi::TagFetchJob *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
-    Q_FOREACH (const Akonadi::Tag &tag, fetchJob->tags()) {
+    const Akonadi::Tag::List lstTags = fetchJob->tags();
+    for (const Akonadi::Tag &tag : lstTags) {
         d->mTagList.insert(tag.url(), tag.name());
     }
 
@@ -191,9 +192,7 @@ void FilterManager::slotTagChanged(const Akonadi::Tag &tag)
 
 void FilterManager::slotTagRemoved(const Akonadi::Tag &tag)
 {
-    if (d->mTagList.contains(tag.url())) {
-        d->mTagList.remove(tag.url());
-    }
+    d->mTagList.remove(tag.url());
     Q_EMIT tagListingFinished();
 }
 
@@ -232,7 +231,7 @@ void FilterManager::filter(const Akonadi::Item::List &messages, FilterManager::F
     QList<qint64> itemIds;
 
     itemIds.reserve(messages.size());
-    foreach (const Akonadi::Item &item, messages) {
+    for (const Akonadi::Item &item : messages) {
         itemIds << item.id();
     }
 
@@ -244,7 +243,7 @@ void FilterManager::filter(const Akonadi::Item::List &messages, SearchRule::Requ
     QList<qint64> itemIds;
 
     itemIds.reserve(messages.size());
-    foreach (const Akonadi::Item &item, messages) {
+    for (const Akonadi::Item &item : messages) {
         itemIds << item.id();
     }
     d->mMailFilterAgentInterface->applySpecificFilters(itemIds, static_cast<int>(requiredPart), listFilters);
@@ -267,7 +266,7 @@ void FilterManager::appendFilters(const QList<MailCommon::MailFilter *> &filters
 {
     beginUpdate();
     if (replaceIfNameExists) {
-        foreach (const MailCommon::MailFilter *newFilter, filters) {
+        for (const MailCommon::MailFilter *newFilter : filters) {
             int numberOfFilters = d->mFilters.count();
             for (int i = 0; i < numberOfFilters; ++i) {
                 MailCommon::MailFilter *filter = d->mFilters.at(i);
