@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -29,7 +29,7 @@ class MAILCOMMON_EXPORT InvalidFilterWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit InvalidFilterWidget(QWidget *parent = Q_NULLPTR);
+    explicit InvalidFilterWidget(QWidget *parent = nullptr);
     ~InvalidFilterWidget();
 
     void setInvalidFilters(const QVector<MailCommon::InvalidFilterInfo> &lst);
