@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2009-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -42,7 +42,7 @@ class MAILCOMMON_EXPORT EntityCollectionOrderProxyModel : public Akonadi::Entity
 {
     Q_OBJECT
 public:
-    explicit EntityCollectionOrderProxyModel(QObject *parent = Q_NULLPTR);
+    explicit EntityCollectionOrderProxyModel(QObject *parent = nullptr);
 
     virtual ~EntityCollectionOrderProxyModel();
 
