@@ -43,17 +43,17 @@ class Q_DECL_HIDDEN SnippetsManager::Private
 public:
     Private(SnippetsManager *qq, QWidget *parent)
         : q(qq),
-          mModel(Q_NULLPTR),
-          mSelectionModel(Q_NULLPTR),
-          mActionCollection(Q_NULLPTR),
-          mEditor(Q_NULLPTR),
-          mAddSnippetAction(Q_NULLPTR),
-          mEditSnippetAction(Q_NULLPTR),
-          mDeleteSnippetAction(Q_NULLPTR),
-          mAddSnippetGroupAction(Q_NULLPTR),
-          mEditSnippetGroupAction(Q_NULLPTR),
-          mDeleteSnippetGroupAction(Q_NULLPTR),
-          mInsertSnippetAction(Q_NULLPTR),
+          mModel(nullptr),
+          mSelectionModel(nullptr),
+          mActionCollection(nullptr),
+          mEditor(nullptr),
+          mAddSnippetAction(nullptr),
+          mEditSnippetAction(nullptr),
+          mDeleteSnippetAction(nullptr),
+          mAddSnippetGroupAction(nullptr),
+          mEditSnippetGroupAction(nullptr),
+          mDeleteSnippetGroupAction(nullptr),
+          mInsertSnippetAction(nullptr),
           mParent(parent),
           mDirty(false)
     {
@@ -257,7 +257,7 @@ void SnippetsManager::Private::deleteSnippet()
     const QString snippetName = index.data(SnippetsModel::NameRole).toString();
 
     if (KMessageBox::warningContinueCancel(
-                0,
+                nullptr,
                 xi18nc("@info",
                        "Do you really want to remove snippet \"%1\"?<nl/>"
                        "<warning>There is no way to undo the removal.</warning>", snippetName),
@@ -327,7 +327,7 @@ void SnippetsManager::Private::deleteSnippetGroup()
 
     if (mModel->rowCount(groupIndex) > 0) {
         if (KMessageBox::warningContinueCancel(
-                    0,
+                    nullptr,
                     xi18nc("@info",
                            "Do you really want to remove group \"%1\" along with all its snippets?<nl/>"
                            "<warning>There is no way to undo the removal.</warning>", groupName),
@@ -337,7 +337,7 @@ void SnippetsManager::Private::deleteSnippetGroup()
         }
     } else {
         if (KMessageBox::warningContinueCancel(
-                    0,
+                    nullptr,
                     i18nc("@info",
                           "Do you really want to remove group \"%1\"?", groupName),
                     QString(),
@@ -545,7 +545,7 @@ void SnippetsManager::Private::save()
     KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kmailsnippetrc"), KConfig::NoGlobals);
 
     // clear everything
-    foreach (const QString &group, config->groupList()) {
+    for (const QString &group : config->groupList()) {
         config->deleteGroup(group);
     }
 
@@ -586,9 +586,9 @@ void SnippetsManager::Private::save()
         group.writeEntry("variablesCount", variablesCount);
 
         int counter = 0;
-        QMapIterator<QString, QString> it(mSavedVariables);
-        while (it.hasNext()) {
-            it.next();
+        QMap<QString, QString>::const_iterator it = mSavedVariables.cbegin();
+        const QMap<QString, QString>::const_iterator itEnd = mSavedVariables.cend();
+        for (; it != itEnd; ++it) {
             group.writeEntry(QStringLiteral("variableName_%1").arg(counter), it.key());
             group.writeEntry(QStringLiteral("variableValue_%1").arg(counter), it.value());
             counter++;
